@@ -312,12 +312,16 @@ class Client:
         execution_side: str = "",
         direction: str = "",
         subaccount_id: str = "",
+        skip: int = 0,
+        limit: int = 0
     ):
         req = spot_exchange_rpc_pb.TradesRequest(
             market_id=market_id,
             execution_side=execution_side,
             direction=direction,
             subaccount_id=subaccount_id,
+            skip=skip,
+            limit=limit
         )
         return self.stubSpotExchange.Trades(req)
 
@@ -343,12 +347,16 @@ class Client:
         execution_side: str = "",
         direction: str = "",
         subaccount_id: str = "",
+        skip: int = 0,
+        limit: int = 0
     ):
         req = spot_exchange_rpc_pb.StreamTradesRequest(
             market_id=market_id,
             execution_side=execution_side,
             direction=direction,
             subaccount_id=subaccount_id,
+            skip=skip,
+            limit=limit
         )
         return self.stubSpotExchange.StreamTrades(req)
 
@@ -401,9 +409,9 @@ class Client:
         )
         return self.stubDerivativeExchange.Orders(req)
 
-    def get_derivative_trades(self, market_id: str, subaccount_id: str = ""):
+    def get_derivative_trades(self, market_id: str, subaccount_id: str = "", execution_side: str = "", direction: str = "", skip: int = 0, limit: int = 0):
         req = derivative_exchange_rpc_pb.TradesRequest(
-            market_id=market_id, subaccount_id=subaccount_id
+            market_id=market_id, subaccount_id=subaccount_id, execution_side=execution_side, direction=direction, skip=skip, limit=limit
         )
         return self.stubDerivativeExchange.Trades(req)
 
@@ -423,9 +431,9 @@ class Client:
         )
         return self.stubDerivativeExchange.StreamOrders(req)
 
-    def stream_derivative_trades(self, market_id: str, subaccount_id: str = ""):
+    def stream_derivative_trades(self, market_id: str, subaccount_id: str = "", execution_side: str = "", direction: str = "", skip: int = 0, limit: int = 0):
         req = derivative_exchange_rpc_pb.StreamTradesRequest(
-            market_id=market_id, subaccount_id=subaccount_id
+            market_id=market_id, subaccount_id=subaccount_id, execution_side=execution_side, direction=direction, skip=skip, limit=limit
         )
         return self.stubDerivativeExchange.StreamTrades(req)
 
